{"00000:1": "

    <head>\n<title>{{ page_title }}</title>\n<meta http-equiv="content-type" content="text/html; charset=utf-8" />\n<meta name="description" content="" />\n<meta name="keywords" content="" />\n<noscript>\n<link rel="stylesheet" href="/css/5grid/core.css" />\n<link rel="stylesheet" href="/css/5grid/core-desktop.css" />\n<link rel="stylesheet" href="/css/5grid/core-1200px.css" />\n<link rel="stylesheet" href="/css/5grid/core-noscript.css" />\n<link rel="stylesheet" href="/css/style.css" />\n<link rel="stylesheet" href="/css/style-desktop.css" />\n</noscript>\n<script src="/css/5grid/jquery.js"></script>\n<script src="/css/5grid/init.js?use=mobile,desktop,1000px&amp;mobileUI=1&amp;mobileUI.theme=none&amp;mobileUI.openerWidth=52"></script>\n<!--[if IE 9]><link rel="stylesheet" href="/css/style-ie9.css" /><![endif]-->\n<link rel="stylesheet" href="/css/pygments.css" />\n</head>\n

\n"}